document.addEventListener('DOMContentLoaded', () => {
  // Mobile menu toggle
  const menuToggle = document.querySelector('.menu-toggle');
  const navLinks = document.querySelector('.nav-links');
  
  menuToggle?.addEventListener('click', () => {
    navLinks.classList.toggle('active');
  });

  // WebRTC implementation
  let localStream;
  const localVideo = document.getElementById('localVideo');
  const conference = document.getElementById('conference');
  const startButton = document.getElementById('startMeeting');
  const toggleVideoButton = document.getElementById('toggleVideo');
  const toggleAudioButton = document.getElementById('toggleAudio');
  const endCallButton = document.getElementById('endCall');

  async function startMeeting() {
    try {
      localStream = await navigator.mediaDevices.getUserMedia({
        video: true,
        audio: true
      });
      
      localVideo.srcObject = localStream;
      conference.classList.remove('hidden');
      document.querySelector('.hero').classList.add('hidden');
    } catch (err) {
      console.error('Error accessing media devices:', err);
      alert('Unable to access camera and microphone. Please ensure you have granted the necessary permissions.');
    }
  }

  function toggleVideo() {
    const videoTrack = localStream.getVideoTracks()[0];
    videoTrack.enabled = !videoTrack.enabled;
    toggleVideoButton.classList.toggle('disabled');
  }

  function toggleAudio() {
    const audioTrack = localStream.getAudioTracks()[0];
    audioTrack.enabled = !audioTrack.enabled;
    toggleAudioButton.classList.toggle('disabled');
  }

  function endCall() {
    localStream.getTracks().forEach(track => track.stop());
    conference.classList.add('hidden');
    document.querySelector('.hero').classList.remove('hidden');
  }

  startButton?.addEventListener('click', startMeeting);
  toggleVideoButton?.addEventListener('click', toggleVideo);
  toggleAudioButton?.addEventListener('click', toggleAudio);
  endCallButton?.addEventListener('click', endCall);
});